@@ -1,12 +1,17 @@
 """
 Constants used in protocol design, specification, and checking
+
+    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
+        for more details.
+    :license: BSD, see LICENSE for more details
+
 """
 from .unit import Unit
 
 SBS_FORMAT_SHAPES = {
     "SBS24": {"rows": 4, "columns": 6},
     "SBS96": {"rows": 8, "columns": 12},
-    "SBS384": {"rows": 16, "columns": 24}
+    "SBS384": {"rows": 16, "columns": 24},
 }
 
 AGAR_CLLD_THRESHOLD = Unit("0.009740:picofarad") * 15
@@ -28,5 +33,5 @@ SPREAD_PATH = [
     (-0.41123474922617687, -0.3063245841015375),
     (0.12965691965919526, -0.5156955527920548),
     (0.6243159222654036, -0.14191423819668741),
-    (0.563207308766221, 0.5152506858187523)
+    (0.563207308766221, 0.5152506858187523),
 ]
