@@ -1,7 +1,7 @@
 """
 Contains all the Autoprotocol Instruction objects
 
-    :copyright: 2018 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
@@ -15,6 +15,7 @@ class Instruction(object):
     """Base class for an instruction that is to later be encoded as JSON.
 
     """
+
     builders = InstructionBuilders()
 
     def __init__(self, op, data):
@@ -24,7 +25,7 @@ class Instruction(object):
         self.__dict__.update(self.data)
 
     def __repr__(self):
-        return "Instruction({}, {})".format(self.op, self.data)
+        return f"Instruction({self.op}, {self.data})"
 
     def _as_AST(self):
         """generates a Python object representation of Autoprotocol JSON
@@ -73,11 +74,17 @@ class Instruction(object):
             return item is None or item == [] or item == {}
 
         if isinstance(data, dict):
-            return {k: Instruction._remove_empty_fields(v) for k, v in
-                    data.items() if not filter_criteria(v)}
+            return {
+                k: Instruction._remove_empty_fields(v)
+                for k, v in data.items()
+                if not filter_criteria(v)
+            }
         if isinstance(data, list):
-            return [Instruction._remove_empty_fields(_) for _ in data
-                    if not filter_criteria(_)]
+            return [
+                Instruction._remove_empty_fields(_)
+                for _ in data
+                if not filter_criteria(_)
+            ]
         return data
 
 
@@ -109,12 +116,13 @@ class MagneticTransfer(Instruction):
     magnetic_head: str
         Head-type used for this instruction
     """
+
     builders = MagneticTransferBuilders()
 
     max_objects = 8
     heads = {
         "96-deep": ["96-v-kf", "96-deep-kf", "96-deep"],
-        "96-pcr": ["96-pcr", "96-v-kf", "96-flat", "96-flat-uv"]
+        "96-pcr": ["96-pcr", "96-v-kf", "96-flat", "96-flat-uv"],
     }
 
     def __init__(self, groups, magnetic_head):
@@ -122,41 +130,35 @@ class MagneticTransfer(Instruction):
 
         if not all(len(_) == 1 for _ in sub_ops):
             raise ValueError(
-                "Not all sub-operations in groups {} contain a single "
-                "sub-operation.".format(groups)
+                f"Not all sub-operations in groups {groups} contain a single "
+                f"sub-operation."
             )
 
         containers = {list(_.values()).pop()["object"] for _ in sub_ops}
         valid_container_types = all(
-            _.container_type.shortname in self.heads[magnetic_head]
-            for _ in containers
+            _.container_type.shortname in self.heads[magnetic_head] for _ in containers
         )
         if not valid_container_types:
             raise ValueError(
-                "Not all containers: {} are in the allowed container_types: {} "
-                "for head_type: {}"
-                "".format(containers, self.heads[magnetic_head], magnetic_head)
+                f"Not all containers: {containers} are in the allowed "
+                f"container_types: {self.heads[magnetic_head]} for head_type: "
+                f"{magnetic_head}"
             )
 
         # a new tip is used for each group
         if len(groups) + len(containers) > self.max_objects:
             raise RuntimeError(
-                "Only {} total objects can be used within the same instruction "
-                "and {} containers: {} were specified in addition to {} groups "
-                "where each group requires a new tip object."
-                "".format(
-                    self.max_objects, len(containers), containers, len(groups)
-                )
+                f"Only {self.max_objects} total objects can be used within the "
+                f"same instruction and {len(containers)} "
+                f"containers: {containers} were specified in addition to "
+                f"{len(groups)} groups where each group requires a new "
+                f"tip object."
             )
 
-        magnetic_transfer = {
-            "groups": groups,
-            "magnetic_head": magnetic_head
-        }
+        magnetic_transfer = {"groups": groups, "magnetic_head": magnetic_head}
 
         super(MagneticTransfer, self).__init__(
-            op="magnetic_transfer",
-            data=magnetic_transfer
+            op="magnetic_transfer", data=magnetic_transfer
         )
 
 
@@ -207,10 +209,20 @@ class Dispense(Instruction):
 
     builders = DispenseBuilders()
 
-    def __init__(self, object, columns, reagent=None, resource_id=None,
-                 reagent_source=None, step_size=None, flowrate=None,
-                 nozzle_position=None, pre_dispense=None, shape=None,
-                 shake_after=None):
+    def __init__(
+        self,
+        object,
+        columns,
+        reagent=None,
+        resource_id=None,
+        reagent_source=None,
+        step_size=None,
+        flowrate=None,
+        nozzle_position=None,
+        pre_dispense=None,
+        shape=None,
+        shake_after=None,
+    ):
 
         disp = {
             "object": object,
@@ -223,16 +235,17 @@ class Dispense(Instruction):
             "flowrate": flowrate,
             "nozzle_position": nozzle_position,
             "shape": shape,
-            "shake_after": shake_after
+            "shake_after": shake_after,
         }
 
         source_fields = ["reagent", "resource_id", "reagent_source"]
         sources = {_: disp[_] for _ in source_fields}
         if sum([_ is not None for _ in sources.values()]) != 1:
             raise ValueError(
-                "Exactly one of `reagent`, `resource_id`, and "
-                "`reagent_source` must be specified for Dispense, "
-                "but got {}.".format(sources))
+                f"Exactly one of `reagent`, `resource_id`, and "
+                f"`reagent_source` must be specified for Dispense, but got "
+                f"{sources}."
+            )
 
         disp = {k: v for k, v in disp.items() if v is not None}
 
@@ -270,10 +283,8 @@ class AcousticTransfer(Instruction):
     def __init__(self, groups, droplet_size):
         super(AcousticTransfer, self).__init__(
             op="acoustic_transfer",
-            data={
-                "groups": groups,
-                "droplet_size": droplet_size
-            })
+            data={"groups": groups, "droplet_size": droplet_size},
+        )
 
 
 class Spin(Instruction):
@@ -304,14 +315,15 @@ class Spin(Instruction):
 
     """
 
-    def __init__(self, object, acceleration, duration, flow_direction=None,
-                 spin_direction=None):
+    def __init__(
+        self, object, acceleration, duration, flow_direction=None, spin_direction=None
+    ):
         spin_json = {
             "object": object,
             "acceleration": acceleration,
             "duration": duration,
             "flow_direction": flow_direction,
-            "spin_direction": spin_direction
+            "spin_direction": spin_direction,
         }
 
         super(Spin, self).__init__(op="spin", data=spin_json)
@@ -369,22 +381,29 @@ class Thermocycle(Instruction):
     ValueError
         If melting curve parameters are specified but dyes isn't
     """
+
     builders = ThermocycleBuilders()
 
-    def __init__(self, object, groups, volume="25:microliter", dataref=None,
-                 dyes=None, melting=None, lid_temperature=None):
+    def __init__(
+        self,
+        object,
+        groups,
+        volume="25:microliter",
+        dataref=None,
+        dyes=None,
+        melting=None,
+        lid_temperature=None,
+    ):
 
         qpcr_params = [dyes, dataref]
         if any(qpcr_params) and not all(qpcr_params):
             raise ValueError(
-                "either dyes {} or dataref {} was specified, but both are "
-                "required for qPCR".format(dyes, dataref)
+                f"either dyes {dyes} or dataref {dataref} was specified, but "
+                f"both are required for qPCR"
             )
 
         if melting and any(melting.values()) and not dyes:
-            raise ValueError(
-                "melting: {} was specified, but dyes was not".format(melting)
-            )
+            raise ValueError(f"melting: {melting} was specified, but dyes was not")
 
         thermocycle = {
             "object": object,
@@ -393,7 +412,7 @@ class Thermocycle(Instruction):
             "dataref": dataref,
             "dyes": dyes,
             "melting": melting,
-            "lid_temperature": lid_temperature
+            "lid_temperature": lid_temperature,
         }
 
         super(Thermocycle, self).__init__(op="thermocycle", data=thermocycle)
@@ -427,23 +446,35 @@ class Incubate(Instruction):
         Carbon dioxide percentage
 
     """
-    WHERE = ["ambient", "warm_30", "warm_37", "cold_4", "cold_20", "cold_80"]
 
-    def __init__(self, object, where, duration, shaking=False, co2=0,
-                 target_temperature=None, shaking_params=None):
+    WHERE = ["ambient", "warm_30", "warm_35", "warm_37", "cold_4", "cold_20", "cold_80"]
+
+    def __init__(
+        self,
+        object,
+        where,
+        duration,
+        shaking=False,
+        co2=0,
+        target_temperature=None,
+        shaking_params=None,
+    ):
         if where not in self.WHERE:
-            raise ValueError("Specified `where` not contained in: %s" % ", "
-                             "".join(self.WHERE))
+            raise ValueError(
+                "Specified `where` not contained in: " f"{', '.join(self.WHERE)}"
+            )
         if where == "ambient" and shaking and not shaking_params:
-            raise ValueError("Shaking is only possible for ambient incubation "
-                             "if 'shaking_params' are specified.")
+            raise ValueError(
+                "Shaking is only possible for ambient incubation "
+                "if 'shaking_params' are specified."
+            )
 
         incubate_json = {
             "object": object,
             "where": where,
             "duration": duration,
             "shaking": shaking,
-            "co2_percent": co2
+            "co2_percent": co2,
         }
         if target_temperature:
             incubate_json["target_temperature"] = target_temperature
@@ -452,6 +483,45 @@ class Incubate(Instruction):
         super(Incubate, self).__init__(op="incubate", data=incubate_json)
 
 
+class Agitate(Instruction):
+    """
+    Agitate sample(s) in a container in a specific condition for a given
+    duration. Once the duration has elapsed, sample(s) will be returned
+    to specified storage condition until it is used in the next
+    instruction.
+
+    Parameters
+    ----------
+    object : ref or str
+        The container to be agitated
+    mode : Enum(["vortex", "invert", "roll", "stir_bar"])
+        Specifies the mode of agitation
+    speed : Unit or str
+        Speed to agitate container at
+    duration : Unit or str
+        Length of time to agitate container
+    temperature : Unit or str
+        Temperature to agitate container at
+    mode_params : dict, optional
+        Dictionary containing mode params for agitation modes
+    """
+
+    def __init__(
+        self, object, mode, speed, duration, temperature=None, mode_params=None
+    ):
+        agitate_json = {
+            "object": object,
+            "mode": mode,
+            "duration": duration,
+            "speed": speed,
+        }
+        if mode_params:
+            agitate_json["mode_params"] = mode_params
+        if temperature:
+            agitate_json["temperature"] = temperature
+        super(Agitate, self).__init__(op="agitate", data=agitate_json)
+
+
 class IlluminaSeq(Instruction):
     """
     Load aliquots into specified lanes for Illumina sequencing.
@@ -489,8 +559,9 @@ class IlluminaSeq(Instruction):
 
     """
 
-    def __init__(self, flowcell, lanes, sequencer, mode, index, library_size,
-                 dataref, cycles):
+    def __init__(
+        self, flowcell, lanes, sequencer, mode, index, library_size, dataref, cycles
+    ):
         seq = {
             "flowcell": flowcell,
             "lanes": lanes,
@@ -499,7 +570,7 @@ class IlluminaSeq(Instruction):
             "index": index,
             "library_size": library_size,
             "dataref": dataref,
-            "cycles": cycles
+            "cycles": cycles,
         }
 
         super(IlluminaSeq, self).__init__(op="illumina_sequence", data=seq)
@@ -531,12 +602,7 @@ class SangerSeq(Instruction):
     """
 
     def __init__(self, object, wells, dataref, type, primer=None):
-        seq = {
-            "type": type,
-            "object": object,
-            "wells": wells,
-            "dataref": dataref
-        }
+        seq = {"type": type, "object": object, "wells": wells, "dataref": dataref}
         if primer and type == "rca":
             seq["primer"] = primer
         super(SangerSeq, self).__init__(op="sanger_sequence", data=seq)
@@ -566,14 +632,17 @@ class GelSeparate(Instruction):
     """
 
     def __init__(self, objects, volume, matrix, ladder, duration, dataref):
-        super(GelSeparate, self).__init__(op="gel_separate", data={
-            "objects": objects,
-            "volume": volume,
-            "matrix": matrix,
-            "ladder": ladder,
-            "duration": duration,
-            "dataref": dataref
-        })
+        super(GelSeparate, self).__init__(
+            op="gel_separate",
+            data={
+                "objects": objects,
+                "volume": volume,
+                "matrix": matrix,
+                "ladder": ladder,
+                "duration": duration,
+                "dataref": dataref,
+            },
+        )
 
 
 class GelPurify(Instruction):
@@ -612,17 +681,21 @@ class GelPurify(Instruction):
               {...}]
 
     """
+
     builders = GelPurifyBuilders()
 
     def __init__(self, objects, volume, matrix, ladder, dataref, extract):
-        super(GelPurify, self).__init__(op="gel_purify", data={
-            "objects": objects,
-            "volume": volume,
-            "matrix": matrix,
-            "ladder": ladder,
-            "dataref": dataref,
-            "extract": extract
-        })
+        super(GelPurify, self).__init__(
+            op="gel_purify",
+            data={
+                "objects": objects,
+                "volume": volume,
+                "matrix": matrix,
+                "ladder": ladder,
+                "dataref": dataref,
+                "extract": extract,
+            },
+        )
 
 
 class Absorbance(Instruction):
@@ -664,19 +737,30 @@ class Absorbance(Instruction):
         time to pause before each well read
 
     """
+
     builders = PlateReaderBuilders()
 
-    def __init__(self, object, wells, wavelength, dataref, flashes=25,
-                 incubate_before=None, temperature=None,
-                 settle_time=None):
-        json_dict = {"object": object,
-                     "wells": wells,
-                     "wavelength": wavelength,
-                     "num_flashes": flashes,
-                     "dataref": dataref,
-                     "incubate_before": incubate_before,
-                     "temperature": temperature,
-                     "settle_time": settle_time}
+    def __init__(
+        self,
+        object,
+        wells,
+        wavelength,
+        dataref,
+        flashes=25,
+        incubate_before=None,
+        temperature=None,
+        settle_time=None,
+    ):
+        json_dict = {
+            "object": object,
+            "wells": wells,
+            "wavelength": wavelength,
+            "num_flashes": flashes,
+            "dataref": dataref,
+            "incubate_before": incubate_before,
+            "temperature": temperature,
+            "settle_time": settle_time,
+        }
 
         super(Absorbance, self).__init__(op="absorbance", data=json_dict)
 
@@ -738,14 +822,14 @@ class Fluorescence(Instruction):
                 "calculated_from_wells": []
             }
 
-    manual: str, Unit, optional
-        parameter available within "position_z" to set the distance from
-        the optics to the plate transport.
-    calculated_from_wells: list, WellGroup, Well, optional
-        parameter available within "position_z" to set the distance from
-        the optics to the plate transport.  If specified, the average
-        optimal (maximal signal) distance will be chosen from the list
-        of wells and applied to all measurements.
+        manual: str, Unit, optional
+            parameter available within "position_z" to set the distance from
+            the optics to the plate transport.
+        calculated_from_wells: list, WellGroup, Well, optional
+            parameter available within "position_z" to set the distance from
+            the optics to the plate transport.  If specified, the average
+            optimal (maximal signal) distance will be chosen from the list
+            of wells and applied to all measurements.
     settle_time: Unit, optional
         the time before the start of the measurement, defaults
         to vendor specifications
@@ -757,12 +841,26 @@ class Fluorescence(Instruction):
         specifications
 
     """
+
     builders = PlateReaderBuilders()
 
-    def __init__(self, object, wells, excitation, emission, dataref, flashes=25,
-                 incubate_before=None, temperature=None, gain=None,
-                 detection_mode=None, position_z=None, settle_time=None,
-                 lag_time=None, integration_time=None):
+    def __init__(
+        self,
+        object,
+        wells,
+        excitation,
+        emission,
+        dataref,
+        flashes=25,
+        incubate_before=None,
+        temperature=None,
+        gain=None,
+        detection_mode=None,
+        position_z=None,
+        settle_time=None,
+        lag_time=None,
+        integration_time=None,
+    ):
         json_dict = {
             "object": object,
             "wells": wells,
@@ -777,7 +875,7 @@ class Fluorescence(Instruction):
             "lag_time": lag_time,
             "integration_time": integration_time,
             "detection_mode": detection_mode,
-            "position_z": position_z
+            "position_z": position_z,
         }
 
         super(Fluorescence, self).__init__(op="fluorescence", data=json_dict)
@@ -818,10 +916,19 @@ class Luminescence(Instruction):
         specifications
 
     """
+
     builders = PlateReaderBuilders()
 
-    def __init__(self, object, wells, dataref, incubate_before=None,
-                 temperature=None, settle_time=None, integration_time=None):
+    def __init__(
+        self,
+        object,
+        wells,
+        dataref,
+        incubate_before=None,
+        temperature=None,
+        settle_time=None,
+        integration_time=None,
+    ):
         json_dict = {
             "object": object,
             "wells": wells,
@@ -829,7 +936,7 @@ class Luminescence(Instruction):
             "incubate_before": incubate_before,
             "temperature": temperature,
             "settle_time": settle_time,
-            "integration_time": integration_time
+            "integration_time": integration_time,
         }
 
         super(Luminescence, self).__init__(op="luminescence", data=json_dict)
@@ -864,7 +971,7 @@ class Seal(Instruction):
             "object": object,
             "type": type,
             "mode": mode,
-            "mode_params": mode_params
+            "mode_params": mode_params,
         }
 
         super(Seal, self).__init__(op="seal", data=seal_dict)
@@ -900,18 +1007,15 @@ class Cover(Instruction):
         Flag to retrieve lid from stored location
 
     """
+
     LIDS = ["standard", "universal", "low_evaporation"]
 
     def __init__(self, object, lid="standard", retrieve_lid=None):
         if lid and lid not in self.LIDS:
-            raise ValueError("%s is not a valid lid type" % lid)
-        cover = {
-            "object": object,
-            "lid": lid,
-            "retrieve_lid": retrieve_lid
-        }
+            raise ValueError(f"{lid} is not a valid lid type")
+        cover = {"object": object, "lid": lid, "retrieve_lid": retrieve_lid}
 
-        super(Cover, self).__init__(op='cover', data=cover)
+        super(Cover, self).__init__(op="cover", data=cover)
 
 
 class Uncover(Instruction):
@@ -929,11 +1033,7 @@ class Uncover(Instruction):
 
     def __init__(self, object, store_lid=None):
         super(Uncover, self).__init__(
-            op="uncover",
-            data={
-                "object": object,
-                "store_lid": store_lid
-            }
+            op="uncover", data={"object": object, "store_lid": store_lid}
         )
 
 
@@ -959,11 +1059,19 @@ class FlowCytometry(Instruction):
     remove_coincident_events : bool, optional
         Remove coincident events. Defaults to false.
     """
+
     builders = FlowCytometryBuilders()
 
-    def __init__(self, dataref, samples, lasers, collection_conditions,
-                 width_threshold=None, window_extension=None,
-                 remove_coincident_events=None):
+    def __init__(
+        self,
+        dataref,
+        samples,
+        lasers,
+        collection_conditions,
+        width_threshold=None,
+        window_extension=None,
+        remove_coincident_events=None,
+    ):
 
         instruction = {
             "dataref": dataref,
@@ -972,11 +1080,10 @@ class FlowCytometry(Instruction):
             "collection_conditions": collection_conditions,
             "width_threshold": width_threshold,
             "window_extension": window_extension,
-            "remove_coincident_events": remove_coincident_events
+            "remove_coincident_events": remove_coincident_events,
         }
 
-        super(FlowCytometry, self).__init__(op="flow_cytometry",
-                                            data=instruction)
+        super(FlowCytometry, self).__init__(op="flow_cytometry", data=instruction)
 
 
 class FlowAnalyze(Instruction):
@@ -1101,14 +1208,16 @@ class FlowAnalyze(Instruction):
 
     """
 
-    def __init__(self,
-                 dataref,
-                 FSC,
-                 SSC,
-                 negative_controls,
-                 samples,
-                 colors=None,
-                 positive_controls=None):
+    def __init__(
+        self,
+        dataref,
+        FSC,
+        SSC,
+        negative_controls,
+        samples,
+        colors=None,
+        positive_controls=None,
+    ):
         flow_instr = {"dataref": dataref, "channels": {}}
         flow_instr["channels"]["FSC"] = FSC
         flow_instr["channels"]["SSC"] = SSC
@@ -1151,9 +1260,9 @@ class Oligosynthesize(Instruction):
     """
 
     def __init__(self, oligos):
-        super(Oligosynthesize, self).__init__(op="oligosynthesize", data={
-            "oligos": oligos
-        })
+        super(Oligosynthesize, self).__init__(
+            op="oligosynthesize", data={"oligos": oligos}
+        )
 
 
 class Autopick(Instruction):
@@ -1176,11 +1285,7 @@ class Autopick(Instruction):
     """
 
     def __init__(self, groups, criteria, dataref):
-        pick = {
-            "groups": groups,
-            "dataref": dataref,
-            "criteria": criteria
-        }
+        pick = {"groups": groups, "dataref": dataref, "criteria": criteria}
 
         super(Autopick, self).__init__(op="autopick", data=pick)
 
@@ -1201,11 +1306,58 @@ class ImagePlate(Instruction):
     """
 
     def __init__(self, object, mode, dataref):
-        super(ImagePlate, self).__init__(op="image_plate", data={
-            "object": object,
+        super(ImagePlate, self).__init__(
+            op="image_plate", data={"object": object, "mode": mode, "dataref": dataref}
+        )
+
+
+class Image(Instruction):
+    """
+    Capture an image of the specified container.
+
+    Parameters
+    ----------
+    ref : Container
+        Container of which to take image.
+    mode : str
+        Angle of image, one of "top", "bottom", "side"
+    num_images : int
+        Number of images taken of the container. Defaults to 1.
+    dataref : str
+        Name of data reference of resulting image
+    backlighting : Bool, optional
+        Whether back-lighting is desired.
+    magnification : float
+        Ratio of sizes of the image projected on the camera
+        sensor compared to the actual size of the object
+        captured. Defaults to 1.0.
+    exposure : dict, optional
+        Parameters to control exposure: "aperture", "iso",
+        and "shutter_speed".
+
+        shutter_speed: Unit, optional
+            Duration that the imaging sensor is exposed.
+        iso : Float, optional
+            Light sensitivity of the imaging sensor.
+        aperture: Float, optional
+            Diameter of the lens opening.
+
+    """
+
+    def __init__(
+        self, ref, mode, dataref, num_images, backlighting, exposure, magnification
+    ):
+        json_dict = {
+            "object": ref,
             "mode": mode,
-            "dataref": dataref
-        })
+            "dataref": dataref,
+            "num_images": num_images,
+            "magnification": magnification,
+            "back_lighting": backlighting,
+            "exposure": exposure,
+        }
+
+        super(Image, self).__init__(op="image", data=json_dict)
 
 
 class Provision(Instruction):
@@ -1235,8 +1387,7 @@ class Provision(Instruction):
 
     def __init__(self, resource_id, dests):
         super(Provision, self).__init__(
-            op="provision",
-            data={"resource_id": resource_id, "to": dests}
+            op="provision", data={"resource_id": resource_id, "to": dests}
         )
 
 
@@ -1255,10 +1406,119 @@ class FlashFreeze(Instruction):
     """
 
     def __init__(self, object, duration):
-        super(FlashFreeze, self).__init__(op="flash_freeze", data={
-            "object": object,
-            "duration": duration
-        })
+        super(FlashFreeze, self).__init__(
+            op="flash_freeze", data={"object": object, "duration": duration}
+        )
+
+
+class Evaporate(Instruction):
+    """
+    Removes liquid or moisture from sample.
+
+    Parameters
+    ----------
+    ref : Container
+        Sample container
+    mode : str
+        Mode of evaporation
+    duration : Unit or str
+        Duration object is processed
+    evaporator_temperature : Unit or str
+        Temperature object is exposed to
+    mode_params : dict
+        Dictionary of parameters for evaporation mode
+    """
+
+    builders = EvaporateBuilders()
+
+    def __init__(self, ref, mode, duration, evaporator_temperature, mode_params):
+        json_dict = {
+            "object": ref,
+            "mode": mode,
+            "duration": duration,
+            "evaporator_temperature": evaporator_temperature,
+            "mode_params": mode_params,
+        }
+        super(Evaporate, self).__init__(op="evaporate", data=json_dict)
+
+
+class SPE(Instruction):
+
+    """
+    Apply a solid phase extraction (spe) technique to a sample.
+
+    Parameters
+    ----------
+    well : Well
+        Well to solid phase extract.
+    cartridge : str
+        Cartridge to use for solid phase extraction.
+    pressure_mode : str
+        The direction of pressure applied to the cartridge to force
+        liquid flow. One of "positive", "negative".
+    load_sample: dict
+        Parameters for applying the sample to the cartridge.
+        Single 'mobile_phase_param'.
+    elute: list(dict)
+        Parameters for applying a mobile phase to the cartridge
+        with one or more solvents. List of 'mobile_phase_params'.
+        Requires `destination_well`.
+    condition: list(dict), optional
+        Parameters for applying a mobile phase to the cartridge
+        with one or more solvents. List of 'mobile_phase_params'.
+    equilibrate: list(dict), optional
+        Parameters for applying a mobile phase to the cartridge
+        with one or more solvents. List of 'mobile_phase_params'.
+    rinse: list(dict), optional
+        Parameters for applying a mobile phase to the cartridge
+        with one or more solvents. List of 'mobile_phase_params'.
+
+        mobile_phase_params:
+            resource_id: str
+                Resource ID of desired solvent.
+            volume: volume
+                Volume added to the cartridge.
+            loading_flowrate: Unit
+                Speed at which volume is added to cartridge.
+            settle_time: Unit
+                Duration for which the solvent remains on the cartridge
+                before a pressure mode is applied.
+            processing_time: Unit
+                Duration for which pressure is applied to the cartridge
+                after `settle_time` has elapsed.
+            flow_pressure: Unit
+                Pressure applied to the column.
+            destination_well: Well
+                Destination well for eluate.  Required parameter for
+                each `elute` mobile phase parameter
+
+    """
+
+    builders = SPEBuilders()
+
+    def __init__(
+        self,
+        well,
+        cartridge,
+        pressure_mode,
+        load_sample,
+        elute,
+        condition,
+        equilibrate,
+        rinse,
+    ):
+        json_dict = {
+            "object": well,
+            "cartridge": cartridge,
+            "pressure_mode": pressure_mode,
+            "condition": condition,
+            "load_sample": load_sample,
+            "rinse": rinse,
+            "elute": elute,
+            "equilibrate": equilibrate,
+        }
+
+        super(SPE, self).__init__(op="spe", data=json_dict)
 
 
 class MeasureConcentration(Instruction):
@@ -1281,12 +1541,55 @@ class MeasureConcentration(Instruction):
     """
 
     def __init__(self, object, volume, dataref, measurement):
-        json_dict = {"object": object,
-                     "volume": volume,
-                     "dataref": dataref,
-                     "measurement": measurement}
-        super(MeasureConcentration, self).__init__(op="measure_concentration",
-                                                   data=json_dict)
+        json_dict = {
+            "object": object,
+            "volume": volume,
+            "dataref": dataref,
+            "measurement": measurement,
+        }
+        super(MeasureConcentration, self).__init__(
+            op="measure_concentration", data=json_dict
+        )
+
+
+class Sonicate(Instruction):
+    """
+    Sonicate wells using high intensity ultrasonic vibrations.
+
+    Parameters
+    ----------
+    wells : Well or WellGroup or list(Well)
+       Wells to be sonicated
+    duration : Unit or str
+        Duration for which to sonicate wells
+    mode: Enum({"bath", "horn"})
+        Sonicating method to be used, must be "horn" or "bath". Sonicate
+        mode "horn" uses metal probe to create a localized shear force
+        directly in the sample media; "bath" mode applies ultrasound to
+        wells held inside a bath.
+    temperature: Unit or str, optional
+        Temperature at which the sample is kept during sonication. Optional,
+        defaults to ambient
+    frequency: Unit or str, optional
+        Frequency of the ultrasonic wave, usually indicated in kHz.
+        Optional; defaults to the most commonly used frequency for each
+        mode: 20 kHz for `horn`, and 40 kHz for `bath` mode
+    mode_params: Dict
+        Dictionary containing mode parameters for the specified mode.
+
+    """
+
+    def __init__(self, wells, duration, mode, mode_params, frequency, temperature):
+        json_dict = {
+            "wells": wells,
+            "duration": duration,
+            "frequency": frequency,
+            "mode": mode,
+            "mode_params": mode_params,
+        }
+        if temperature:
+            json_dict["temperature"] = temperature
+        super(Sonicate, self).__init__(op="sonicate", data=json_dict)
 
 
 class MeasureMass(Instruction):
@@ -1349,7 +1652,7 @@ class CountCells(Instruction):
             "wells": wells,
             "volume": volume,
             "dataref": dataref,
-            "labels": labels
+            "labels": labels,
         }
 
         super(CountCells, self).__init__(op="count_cells", data=json_dict)
@@ -1380,10 +1683,19 @@ class Spectrophotometry(Instruction):
         that dictates how the obj should be incubated with shaking before any of
         the groups are executed.
     """
+
     builders = SpectrophotometryBuilders()
 
-    def __init__(self, dataref, object, groups, interval=None,
-                 num_intervals=None, temperature=None, shake_before=None):
+    def __init__(
+        self,
+        dataref,
+        object,
+        groups,
+        interval=None,
+        num_intervals=None,
+        temperature=None,
+        shake_before=None,
+    ):
         spec = {
             "dataref": dataref,
             "object": object,
@@ -1391,11 +1703,10 @@ class Spectrophotometry(Instruction):
             "interval": interval,
             "num_intervals": num_intervals,
             "temperature": temperature,
-            "shake_before": shake_before
+            "shake_before": shake_before,
         }
 
-        super(Spectrophotometry, self).__init__(op="spectrophotometry",
-                                                data=spec)
+        super(Spectrophotometry, self).__init__(op="spectrophotometry", data=spec)
 
 
 class LiquidHandle(Instruction):
@@ -1418,6 +1729,7 @@ class LiquidHandle(Instruction):
     mode_params : dict, optional
         See Also :meth:`LiquidHandle.builders.instruction_mode_params`
     """
+
     builders = LiquidHandleBuilders()
 
     def __init__(self, locations, shape=None, mode=None, mode_params=None):
@@ -1425,10 +1737,7 @@ class LiquidHandle(Instruction):
             "locations": locations,
             "shape": shape,
             "mode": mode,
-            "mode_params": mode_params
+            "mode_params": mode_params,
         }
 
-        super(LiquidHandle, self).__init__(
-            op="liquid_handle",
-            data=data
-        )
+        super(LiquidHandle, self).__init__(op="liquid_handle", data=data)
